# edgegallery_face_recognition
face_recognition

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.4
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import edgegallery_face_recognition 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import edgegallery_face_recognition
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import edgegallery_face_recognition
from edgegallery_face_recognition.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = edgegallery_face_recognition.DefaultApi(edgegallery_face_recognition.ApiClient(configuration))

try:
    # helloworld
    api_response = api_instance.root_get()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DefaultApi->root_get: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://{HOST}/v1/face-recognition*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**root_get**](docs/DefaultApi.md#root_get) | **GET** / | helloworld
*RecognitionApi* | [**recognition_post**](docs/RecognitionApi.md#recognition_post) | **POST** /recognition | images face recognition
*UploadApi* | [**upload_post**](docs/UploadApi.md#upload_post) | **POST** /upload | upload images
*VideoApi* | [**add_url**](docs/VideoApi.md#add_url) | **POST** /video | video face recognition

## Documentation For Models

 - [Body](docs/Body.md)
 - [Body1](docs/Body1.md)
 - [Body2](docs/Body2.md)

## Documentation For Authorization

 All endpoints do not require authorization.


## Author


